/*
 *  field_types.h - The different types of data fields that can be
 *                  displayed, and their structs.
 *                  This file is part of the FreeLCD package.
 *
 *  $Id: field_types.h,v 1.2 2003/11/02 21:35:35 unicorn Exp $
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *  Copyright (c) 2003, Jeroen van den Berg <unicorn@hippie.nu>
 */


#ifndef _FIELD_TYPES_H
#define _FIELD_TYPES_H

typedef enum
{
  F_NONE = 0,
  F_LABEL,
  F_SCROLLTEXT,
  F_HEADER,
  F_TIME,
  F_TIMESPAN,
  F_DATE,
  F_SCALAR,
  F_PERCENTAGE,
  F_HISTOGRAM,
  F_PIXMAP
}
data_type;

typedef struct
{
  unsigned char hours;
  unsigned char minutes;
  unsigned char seconds;
  unsigned int  milliseconds;
}
flcd_time;

typedef struct
{
  unsigned long seconds;
  unsigned int  milliseconds;
}
flcd_timespan;

typedef struct
{
  unsigned char day;
  unsigned char month;
  int           year;
}
flcd_date;

typedef struct
{
  unsigned int samples;
  int          min;
  int          max;
  int          *data;
}
flcd_histogram;

typedef struct
{
  unsigned int width;
  unsigned int height;
  char         *pixmap; /*< RGBA */
}
flcd_pixmap;



typedef struct
{
  data_type           type;
  char                defined;
  char                valid;
  char                changed;
  union
    {
      long            scalar;
      double          percentage;
      char            *text;
      flcd_time       time;
      flcd_timespan   timespan;
      flcd_date       date;
      flcd_histogram  histogram;
      flcd_pixmap     pixmap;
    }
  data;
}
field;

#endif /* Multiple include guard */
