/*
 *  xmalloc.c - Wrappers for malloc() and realloc(). 
 *              This file is part of the FreeLCD package.
 *
 *  $Id: xmalloc.c,v 1.2 2003/01/26 21:53:25 unicorn Exp $
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *  Copyright (c) 2002, 2003, Jeroen van den Berg <unicorn@hippie.nu>
 */

#include <stdlib.h>
#include <syslog.h>
#include <string.h>

#include "xmalloc.h"

/*------------------------------------------------------------- xmalloc --*/
void *
xmalloc (size_t size)
{
  void *alloc = malloc (size);

  if (alloc == 0)
    {
      syslog (LOG_ERR, "out of memory (malloc)");
      exit (EXIT_FAILURE);
    }

  return alloc;
}

/*------------------------------------------------------------ xrealloc --*/
void *
xrealloc (void *ptr, size_t size)
{
  void *alloc;

  if (ptr == 0)
    return xmalloc (size);

  alloc = realloc (ptr, size);
  if (alloc == 0)
    {
      syslog (LOG_ERR, "out of memory (realloc)");
      exit (EXIT_FAILURE);
    }

  return alloc;
}

/*------------------------------------------------------------- xstrdup --*/
char *
xstrdup (const char *str)
{
  char *copy = strdup (str);

  if (copy == 0)
    {
      syslog (LOG_ERR, "out of memory (strdup)");
      exit (EXIT_FAILURE);
    }

  return copy;
}
