/*
 *  driver.h - Interface definition for driver modules.
 *             This file is part of the FreeLCD package.
 *
 *  $Id: driver.h,v 1.5 2003/03/23 20:14:11 unicorn Exp $
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *  Copyright (c) 2002, 2003, Jeroen van den Berg <unicorn@hippie.nu>
 */


#ifndef _FLCDD_DRIVER_H
#define _FLCDD_DRIVER_H

#include "renderers/charcanvas.h"
#include "common/xmlt.h"

typedef enum
{
  DRV_CHARACTER, DRV_GRAPHICAL
}
drv_type;

typedef struct
{
  int width;
  int height;
}
drv_dimensions;
    
/*  Function returns a driver handle, configured with the given data. */
void*
drv_create_handle (xml_node *config);

/*  Release all resources held by the driver handle. */
void
drv_destroy_handle (void *handle);

/*  Bind a driver handle to a backend (e.g. the serial port, or ncurses). */
void
drv_bind_backend (void *handle, void *backend); 

/*  Display the canvas. This is either a cc_canvas or a cg_canvas, depending
 *  on the driver type. */
void
drv_process_canvas (void *handle, void *canvas);

/*  Query the type. */
drv_type
drv_get_type (void);

/*  Get the dimensions of the connected device. For character-oriented
 *  displays, the sizes are given in characters. For graphical displays
 *  it's pixels. */
drv_dimensions
drv_get_dimensions (void *handle);

/*  Get information about this driver. The returned char pointer might
 *  need casting to another type, if the field does not contain character
 *  data. All drivers must support at least the following fields:
 *  - "name", a short descriptive name 
 *  - "version", a single character indicating the version. 
 */
const char*
drv_get_info (const char *field);

/*  Return the handle to the backend that is currently bound to the given
 *  handle.
 */
void*
drv_get_backend (void *handle);

#endif /* Multiple include guard */
