/*
 *  text.h - Text handling routinges
 *           This file is part of the FreeLCD package.
 *
 *  $Id: text.h,v 1.2 2003/03/23 20:14:11 unicorn Exp $
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *  Copyright (c) 2002, Jeroen van den Berg <unicorn@hippie.nu>
 */

#ifndef _TEXT_H
#define _TEXT_H

typedef struct
{
  int width;                        /* Specified width ...             */
  int height;                        /* ... and height of the buffer.   */
  int reserved_h;                /* Malloc'ed height.               */
  int cursor_x;                        /* X-position of the cursor.       */
  int cursor_y;                        /* Y-position.                     */
  char *buf;                        /* Pointer to the actual contents. */
}
text_buf;


/* Create a new text buffer */
text_buf *text_buf_malloc (int width, int height);

/* Free a buffer */
void text_buf_free (text_buf * buf);

/* Print some text at the cursor position */
void text_print (text_buf * buf, const char *text);

/* Print some text at the cursor position, with word wrapping */
void text_print_wrap (text_buf * buf, const char *text);

/* Add a centered line */
void
text_add_centered_line (text_buf * buf, const char *text,
                        char filler, char left_end, char right_end);

/* Clip a region from a text buffer and return the region */
text_buf *text_copy_region (const text_buf * buf, int x, int y, int w, int h);

/* Paste a region inside another region */
void
text_paste_region (text_buf * dest, const text_buf * source, int x, int y);

/* Crop lines at the outside */
void text_crop (text_buf * buf, int top, int bottom, int left, int right);

/* Crop all whitespace around text buffer automatically */
void text_autocrop (text_buf * buf);

#endif /* Multiple include guard */
